#
# spec file for package aws-c-compression
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define library_version 1.0.0
%define library_soversion 1_0_0
Name:           aws-c-compression
Version:        0.3.1
Release:        1.1
Summary:        C99 implementation of Huffman encoding/decoding
License:        Apache-2.0
Group:          Development/Libraries/C and C++
URL:            https://github.com/awslabs/aws-c-compression
Source0:        https://github.com/awslabs/%{name}/archive/v%{version}.tar.gz
BuildRequires:  cmake
BuildRequires:  fdupes
BuildRequires:  cmake(aws-c-common)
BuildRequires:  cmake(aws-checksums)
BuildRequires:  ninja

%description
A C99 implementation of Huffman encoding/decoding.

%package -n lib%{name}%{library_soversion}
Summary:        C99 implementation of Huffman encoding/decoding
Group:          System/Libraries

%description -n lib%{name}%{library_soversion}
A C99 implementation of Huffman encoding/decoding.

This package contains the dynamically linked library.

%package devel
Summary:        Development files for aws-c-compression library
Group:          Development/Libraries/C and C++
Requires:       lib%{name}%{library_soversion} = %{version}

%description devel
A C99 implementation of Huffman encoding/decoding.

This package contains the development files.

%prep
%autosetup -p1

%build
%define __builder ninja
%cmake \
    -DCMAKE_BUILD_TYPE=Release
%make_jobs

%check
export LD_LIBRARY_PATH=%{_builddir}/%{name}-%{version}/build
%ctest

%install
%cmake_install

%post -n lib%{name}%{library_soversion} -p /sbin/ldconfig
%postun -n lib%{name}%{library_soversion} -p /sbin/ldconfig

%files -n lib%{name}%{library_soversion}
%doc NOTICE README.md
%license LICENSE
%{_libdir}/*.so.%{library_version}

%files devel
%{_libdir}/cmake/
%{_libdir}/*.so
%{_includedir}/*

%changelog
* Thu Jan 30 2025 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.3.1
  * chore: Modified bug issue template to add checkbox to
    report potential regression. by @ashishdhingra in (#69)
  * Switch CI to use roles by @DmitriyMusatkin in #71
  * A bunch of CMake fixes by @graebm in #72
- Drop acc_fix-cmake-modules-path.patch, fixed upstream
* Thu Oct 24 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.3.0
  * Update CMake to 3.9 by @waahm7 in (#70)
* Mon Feb 19 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.2.18
  * Add github templates and bots by @jmklix in (#61)
  * Fix compiler warning by @graebm in (#62)
  * Added workflow for handling answerable discussions
    by @yasminetalby in (#65)
  * BUILDER_VERSION: v0.9.55 by @graebm in (#66)
* Wed Jun 14 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.2.17
  * Update CI to fix downstream build by @waahm7 in (#57)
  * Update builder version to fix aws-lc build on manylinux1 by @TingDaoK in (#59)
  * Fix warnings in public headers by @waahm7 in (#60)
* Fri Nov 11 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.2.16
  * Add AppVerifier to CI by @TwistedTwigleg in (#56)
  * Fix C++ One Definition Rules (ODR) Violations by @graebm in (#58)
* Fri Sep  2 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.2.15
  * Fallback for target load by @TingDaoK in (#55)
* Tue Oct 12 2021 Jan Engelhardt <jengelh@inai.de>
- Simplify package naming. Replace bogus shlib package name.
* Tue Oct 12 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Initial build
  + Version 0.2.14
